================
Optional plugins
================

.. toctree::
   :maxdepth: 2

   optional/avocado_ec2
   optional/golang
   optional/results
   optional/robot
   optional/varianter_cit
   optional/varianter_pict
   optional/multiplexer
   optional/varianter_yaml_to_mux
